@@ -27,10 +27,7 @@ from svg_ultralight.font_tools.font_info import (
 )
 from svg_ultralight.font_tools.globs import DEFAULT_FONT_SIZE
 from svg_ultralight.query import get_bounding_boxes
-from svg_ultralight.string_conversion import (
-    format_attr_dict,
-    format_number,
-)
+from svg_ultralight.string_conversion import format_attr_dict, format_number
 
 if TYPE_CHECKING:
     import os
@@ -39,6 +36,8 @@ if TYPE_CHECKING:
         _Element as EtreeElement,  # pyright: ignore[reportPrivateUsage]
     )
 
+    from svg_ultralight.attrib_hints import ElemAttrib, OptionalElemAttribMapping
+
 DEFAULT_Y_BOUNDS_REFERENCE = "{[|gjpqyf"
 
 
@@ -99,7 +98,8 @@ def pad_text_ft(
     descent: float | None = None,
     *,
     y_bounds_reference: str | None = None,
-    **attributes: str | float,
+    attrib: OptionalElemAttribMapping = None,
+    **attributes: ElemAttrib,
 ) -> PaddedText:
     """Create a new PaddedText instance using fontTools.
 
@@ -115,11 +115,15 @@ def pad_text_ft(
         extents of the capline reference. This argument is provided to mimic the
         behavior of the query module's `pad_text` function. `pad_text` does no
         inspect font files and relies on Inkscape to measure reference characters.
+    :param attrib: optionally pass additional attributes as a mapping instead of as
+        anonymous kwargs. This is useful for pleasing the linter when unpacking a
+        dictionary into a function call.
     :param attributes: additional attributes to set on the text element. There is a
         chance these will cause the font element to exceed the BoundingBox of the
         PaddedText instance.
     :return: a PaddedText instance with a line_gap defined.
     """
+    attributes.update(attrib or {})
     attributes_ = format_attr_dict(**attributes)
     attributes_.update(get_svg_font_attributes(font))
 
@@ -145,7 +149,8 @@ def pad_text_mix(
     descent: float | None = None,
     *,
     y_bounds_reference: str | None = None,
-    **attributes: str | float,
+    attrib: OptionalElemAttribMapping = None,
+    **attributes: ElemAttrib,
 ) -> PaddedText:
     """Use Inkscape text bounds and fill missing with fontTools.
 
@@ -161,11 +166,15 @@ def pad_text_mix(
         extents of the capline reference. This argument is provided to mimic the
         behavior of the query module's `pad_text` function. `pad_text` does no
         inspect font files and relies on Inkscape to measure reference characters.
+    :param attrib: optionally pass additional attributes as a mapping instead of as
+        anonymous kwargs. This is useful for pleasing the linter when unpacking a
+        dictionary into a function call.
     :param attributes: additional attributes to set on the text element. There is a
         chance these will cause the font element to exceed the BoundingBox of the
         PaddedText instance.
     :return: a PaddedText instance with a line_gap defined.
     """
+    attributes.update(attrib or {})
     elem = new_element("text", text=text, **attributes)
     padded_inkscape = pad_text(inkscape, elem, y_bounds_reference, font=font)
     padded_fonttools = pad_text_ft(
@@ -175,7 +184,7 @@ def pad_text_mix(
         ascent,
         descent,
         y_bounds_reference=y_bounds_reference,
-        **attributes,
+        attrib=attributes,
     )
     bbox = padded_inkscape.unpadded_bbox
     rpad = padded_inkscape.rpad
