@@ -105,6 +105,7 @@ from typing import TYPE_CHECKING, Any, cast
 from fontTools.pens.basePen import BasePen
 from fontTools.pens.boundsPen import BoundsPen
 from fontTools.ttLib import TTFont
+from paragraphs import par
 from svg_path_data import format_svgd_shortest, get_cpts_from_svgd, get_svgd_from_cpts
 
 from svg_ultralight.bounding_boxes.type_bounding_box import BoundingBox
@@ -118,12 +119,82 @@ if TYPE_CHECKING:
 
     from lxml.etree import _Element as EtreeElement
 
+    from svg_ultralight.attrib_hints import ElemAttrib
+
 logging.getLogger("fontTools").setLevel(logging.ERROR)
 
 
-def _split_into_quadratic(
-    *pts: tuple[float, float],
-) -> Iterator[tuple[tuple[float, float], tuple[float, float]]]:
+_ESCAPE_CHARS = {"&": "&amp;", "<": "&lt;", ">": "&gt;", '"': "&quot;", "'": "&apos;"}
+
+
+def _sanitize_svg_data_text(text: str) -> str:
+    """Sanitize a string for use in an SVG data-text attribute.
+
+    :param text: The input string to sanitize.
+    :return: The sanitized string with XML characters escaped.
+    """
+    for char, escape_seq in _ESCAPE_CHARS.items():
+        text = text.replace(char, escape_seq)
+    return text
+
+
+# extract_gpos_kerning is an unfinished attempt to extract kerning from the GPOS
+# table.
+def _get_gpos_kerning(font: TTFont) -> dict[tuple[str, str], int]:
+    """Extract kerning pairs from the GPOS table of a font.
+
+    :param font: A fontTools TTFont object.
+    :return: A dictionary mapping glyph pairs to their kerning values.
+    :raises ValueError: If the font does not have a GPOS table.
+
+    This is the more elaborate kerning that is used in OTF fonts and some TTF fonts.
+    It has several flavors, I'm only implementing glyph-pair kerning (Format 1),
+    because I don't have fonts to test anything else.
+    """
+    if "GPOS" not in font:
+        msg = "Font does not have a GPOS table."
+        raise ValueError(msg)
+
+    gpos = font["GPOS"].table
+    kern_table: dict[tuple[str, str], int] = {}
+
+    type2_lookups = (x for x in gpos.LookupList.Lookup if x.LookupType == 2)
+    subtables = list(it.chain(*(x.SubTable for x in type2_lookups)))
+    for subtable in (x for x in subtables if x.Format == 1):  # glyph-pair kerning
+        for pair_set, glyph1 in zip(subtable.PairSet, subtable.Coverage.glyphs):
+            for pair_value in pair_set.PairValueRecord:
+                glyph2 = pair_value.SecondGlyph
+                value1 = pair_value.Value1
+                xadv = getattr(value1, "XAdvance", None)
+                xpla = getattr(value1, "XPlacement", None)
+                value = xadv or xpla or 0
+                if value != 0:  # only record non-zero kerning values
+                    kern_table[(glyph1, glyph2)] = value
+
+    for subtable in (x for x in subtables if x.Format == 2):  # class-based kerning
+        defs1 = subtable.ClassDef1.classDefs
+        defs2 = subtable.ClassDef2.classDefs
+        record1 = subtable.Class1Record
+        defs1 = {k: v for k, v in defs1.items() if v < len(record1)}
+        for (glyph1, class1), (glyph2, class2) in it.product(
+            defs1.items(), defs2.items()
+        ):
+            class1_record = record1[class1]
+            if class2 < len(class1_record.Class2Record):
+                value1 = class1_record.Class2Record[class2].Value1
+                xadv = getattr(value1, "XAdvance", None)
+                xpla = getattr(value1, "XPlacement", None)
+                value = xadv or xpla or 0
+                if value != 0:
+                    kern_table[(glyph1, glyph2)] = value
+
+    return kern_table
+
+
+_XYTuple = tuple[float, float]
+
+
+def _split_into_quadratic(*pts: _XYTuple) -> Iterator[tuple[_XYTuple, _XYTuple]]:
     """Connect a series of points with quadratic bezier segments.
 
     :param points: a series of at least two (x, y) coordinates.
@@ -183,9 +254,16 @@ class PathPen(BasePen):
 
     def curveTo(self, *pts: tuple[float, float]) -> None:
         """Add a series of cubic bezier segments to the path."""
-        msg = "Cubic Bezier curves not implemented for getting svg path data."
-        raise NotImplementedError(msg)
-        self._cmds.extend(("Q", *map(str, it.chain(*pts))))
+        if len(pts) > 3:
+            msg = par(
+                """I'm uncertain how to decompose these points into cubics (if the
+                goal is to match font rendering in Inkscape and elsewhere. There is
+                function, decomposeSuperBezierSegment, in fontTools, but I cannot
+                find a reference for the algorithm. I'm hoping to run into one in a
+                font file so I have a test case."""
+            )
+            raise NotImplementedError(msg)
+        self._cmds.extend(("C", *map(str, it.chain(*pts))))
 
     def qCurveTo(self, *pts: tuple[float, float]) -> None:
         """Add a series of quadratic bezier segments to the path."""
@@ -252,13 +330,18 @@ class FTFontInfo:
         method would give precedence to the first occurrence. That behavior is copied
         from examples found online.
         """
-        with suppress(KeyError, AttributeError):
+        try:
             kern_tables = cast(
                 "list[dict[tuple[str, str], int]]",
                 [x.kernTable for x in self.font["kern"].kernTables],
             )
-            return dict(x for d in reversed(kern_tables) for x in d.items())
-        return {}
+            kern = dict(x for d in reversed(kern_tables) for x in d.items())
+        except (KeyError, AttributeError):
+            kern = {}
+        with suppress(Exception):
+            kern.update(_get_gpos_kerning(self.font))
+
+        return kern
 
     @ft.cached_property
     def hhea(self) -> Any:
@@ -301,7 +384,7 @@ class FTFontInfo:
         svgd = path_pen.svgd
         if not dx or not svgd:
             return svgd
-        cpts = path_pen.cpts
+        cpts = get_cpts_from_svgd(svgd)
         for i, curve in enumerate(cpts):
             cpts[i][:] = [(x + dx, y) for x, y in curve]
         svgd = format_svgd_shortest(get_svgd_from_cpts(cpts))
@@ -453,7 +536,7 @@ class FTTextInfo:
         """
         return self.font_size / self.font.units_per_em
 
-    def new_element(self, **attributes: str | float) -> EtreeElement:
+    def new_element(self, **attributes: ElemAttrib) -> EtreeElement:
         """Return an svg text element with the appropriate font attributes."""
         matrix_vals = (self.scale, 0, 0, -self.scale, 0, 0)
         matrix = f"matrix({' '.join(format_numbers(matrix_vals))})"
@@ -463,7 +546,7 @@ class FTTextInfo:
             attributes["stroke-width"] = float(stroke_width) / self.scale
         return new_element(
             "path",
-            data_text=self.text,
+            data_text=_sanitize_svg_data_text(self.text),
             d=self.font.get_text_svgd(self.text),
             **attributes,
         )
