@@ -10,4 +10,4 @@ from svg_ultralight.strings.svg_strings import (
     svg_ints,
 )
 
-__all__ = ["svg_color_tuple", "svg_ints", "svg_float_tuples"]
+__all__ = ["svg_color_tuple", "svg_float_tuples", "svg_ints"]
